## Instalación y Configuración de Dspace-CRIS

### Creación de volumenes

Los volumenes deben ser creados para mantener la persistencia de los archivos subidos a la plataforma. Los comando a ajecutar son:

---
sudo docker volume create solr_data

sudo docker volume create assetstore
___


### Creación de imágenes de contianers
Antes de lanzar la ejecución de un container debe crear las imágenes que contienen todas sus dependencias, en este caso puntual las imágenes para crear el frontend, el backend y solr. Además, de todas las imágenes intermendias  que permiten separar los componentes de software según lo decrito en los Hitos 3.1 y 3.2.. Los comandos son los siguientes:

* creación de las dependencias y de la imagen del frontend. Se debe destacar que este componente queda configurado y corriendo en el puerto 4000
---
cd frontend/srcDependencies

sudo docker build -t img_dspacecris-ui-dependencies:latest --no-cache --progress=plain .

cd ..

sudo docker build -t img_dspacecris-ui:latest --no-cache --progress=plain .
___

Es importante mencionar que la configuración para producción debe cambiar el host y port de los archivos *confi.prod.yml* y *dspace-ui.json*

![config](../figures/ksnip_20240331-235907.png)


* creación de las imagenes de solr, del backend y sus dependencias

---
cd backend/srcDependencies

sudo docker build -t img_dspacecris-dependencies:latest --no-cache --progress=plain .

cd ../api  

sudo docker build -t img_dspacecris:latest --no-cache --progress=plain .

cd ../solr

sudo docker build -t img_solrcris:latest --no-cache --progress=plain .
___

### Crear containers y ejecutarlos

* frontend
---
sudo docker run --network="host" --restart=on-failure:10 --name ctr_dspacecris-ui -d img_dspacecris-ui
___

* backend +  solr
---
sudo docker run --network="host" --restart=on-failure:10 --name ctr_solrcris \
-v solr_data:/var/solr/data/ \
-d img_solrcris

sudo docker run --network="host" --restart=on-failure:10 --name ctr_dspacecris \
-v assetstore:/dspace/assetstore/ \
-d img_dspacecris
___


### Configurar container luego de su puesta en marcha

Una vez creados los container, el container que contiene el backend debe ser intervenido y se deben correr una serie de comandos para configurar la plataforma antes de la puesta en marcha

#### Creación de super user

* Ingresar al container

---
sudo docker exec -it ctr_dspacecris /bin/bash
___

* Creción de admin
---
sudo /dspace/bin/dspace create-administrator
___
Se solicitarán una serie de parámetros, ingresar lo siguiente (o similar, ya que estos son valores de referencia)

- E-mail address: dev.prototipo@uautonoma.cl
- First name: dev
- Last name: prototipo
- pass : dspace



#### Crear jerarquidas de entidades para las "Colecciones"

Comando 1: permite ingresar al docker una vez creado el container, en este caso particular el container de Dspace-CRIS se llama “ctr_dspacecris”

---
sudo docker exec -it ctr_dspacecris /bin/bash


cd /dspace/bin/


/dspace/bin/dspace dsrun org.dspace.app.util.InitializeEntityTypesOnly -d

ó 

/dspace/bin/dspace initialize-entities -f /dspace/config/entities/relationship-types.xml


/dspace/bin/dspace dsrun org.dspace.app.util.InitializeEntities -f /dspace/config/entities/correction-relationship-types.xml


exit
___


### Limpiar contaniers en ejecución en caso de fallas

Al contener volumenes de persistencia, no importa si baja y vuleve a subir los containers, ya que la persistencia permite respaldar todo lo subido a la plataforma. Los comandos para limpiar son:


* Comandos para ver los logs de los contianers en ejecución
---
sudo docker logs ctr_solrcris

sudo docker logs ctr_dspacecris

sudo docker logs ctr_dspacecris-ui
___

* Comandos para reiniciar la ejecución de los containers
---
sudo docker restart ctr_solrcris

sudo docker restart ctr_dspacecris

sudo docker restart ctr_dspacecris-ui
___

* Comandos para detener la ejecución de los containers
---
sudo docker stop ctr_solrcris

sudo docker stop ctr_dspacecris

sudo docker stop ctr_dspacecris-ui
___

* Comandos para eliminar la ejecución de los containers. Antes de lanzar este comando, el container debe esta detenido por falla o por que se ejecuto el comanod STOP 

---
sudo docker rm ctr_solrcris

sudo docker rm ctr_dspacecris

sudo docker rm ctr_dspacecris-ui
___

* Comandos para eliminar las imagenes de los container, debe haber eliminido o detenido todo contianer en ejecución que tenga que ver con estas imágenes antes de poder lanzar estos comandos
---
sudo docker rmi img_solrcris

sudo docker rmi img_dspacecris

sudo docker rmi img_dspacecris-dependencies

sudo docker rmi img_dspacecris-ui

sudo docker rmi img_dspacecris-ui-dependencies
___

## Configuración de SSL con certbot y nginx

Se debe recordar que los sertificados a crear son de *Let's Encrypt* y tienen una duración de 3 meses, si quiere prolongar su duración debe automatizar o realizar manaulmente el proceso de volver a crear o validar el certificado

### Crear archivo de configuración

ingresar a la carpeta /etc/nginx/sites-available y modificar el archivo *default*, este debe quedar con la siguiente estructura. Cabe notar que se estan haciendo las redirecciones al puerto 8080 y al 4000

---
server{

        listen 80 default_server;
        listen [::]:80 default_server;

        server_name repositorio.dev-ua.cl;

        location /server {
                proxy_set_header X-Forwarded-Proto https;
                proxy_set_header X-Forwarded-Host $host;
                proxy_pass http://localhost:8080/server;
        }

        location / {
                # First attempt to serve request as file, then
                # as directory, then fall back to displaying a 404.
                #try_files $uri $uri/ =404;
                proxy_set_header X-Forwarded-Proto https;
                proxy_set_header X-Forwarded-Host $host;
                proxy_pass http://localhost:4000/;
        }

}
___




### Correr comando para crear certificados

Al ejecutar el comando de certbot reconoce la ruta *repositorio.dev-ua.cl* especificada en el archivo *default*

---
sudo service nginx stop

sudo certbot --nginx -d repositorio.dev-ua.cl

sudo service nginx restart
___

